@@ -3,6 +3,8 @@ from wizzi_utils.misc import misc_tools as mt
 from wizzi_utils.pyplot import pyplot_tools as pyplt
 import numpy as np
 
+PLT_MAX_TIME = 2  # close plt after x seconds - minimum 2
+
 
 def find_centers_test():
     """
@@ -39,7 +41,8 @@ def find_centers_test():
                 'location': (0, 0),
                 'resize': 1,
                 'zoomed': False
-            }
+            },
+            max_time=PLT_MAX_TIME
         )
     return
 
