@@ -38,9 +38,12 @@ def load_json(file_path: str, ack: bool = True, tabs: int = 1) -> dict:
     if os.path.exists(file_path):
         ret_dict = json.load(open(file_path))
         if ack:
-            print('{}Loaded: {}. Content: {}'.format(tabs * '\t', file_path, json_to_string(ret_dict)))
+            size_s = mt.file_or_folder_size(file_path)
+            file_msg = '{}({})'.format(file_path, size_s)
+            print('{}{}. {}'.format(tabs * '\t', mt.LOADED.format(file_msg),
+                                    mt.CONTENT.format(json_to_string(ret_dict))))
     else:
-        mt.exception_error('file {} doesnt exists'.format(file_path), tabs)
+        mt.exception_error(mt.NOT_FOUND.format(file_path), real_exception=False, tabs=tabs)
     return ret_dict
 
 
@@ -52,39 +55,35 @@ def load_jsons(files_path: list, ack: bool = True, tabs: int = 1) -> dict:
     """
     all_in_one_dict = {}
     len_keys_json = 0
+    size_s = 0
     for file_path in files_path:
-        j = load_json(file_path, ack=False)
+        size_s += mt.file_or_folder_size(file_path, as_str=False)
+        j = load_json(file_path, ack=False, tabs=tabs)
         len_keys_json += len(j)
         all_in_one_dict.update(j)
-    if ack:
-        print('{}Loaded: {}. Content: {}'.format(tabs * '\t', files_path, json_to_string(all_in_one_dict)))
+
     assert len_keys_json == len(all_in_one_dict), 'Duplicated keys found: {}'.format(files_path)
+    if ack:
+        file_msg = '{}({})'.format(files_path, mt.convert_size(size_s))
+        print('{}{}. {}'.format(tabs * '\t', mt.LOADED.format(file_msg),
+                                mt.CONTENT.format(json_to_string(all_in_one_dict))))
     return all_in_one_dict
 
 
-def save_json(file_path: str, j: dict, indent: int = -1, sort_keys: bool = False, ack: bool = True,
-              tabs: int = 1) -> None:
+def save_json(file_path: str,
+              j: dict,
+              indent: int = -1,
+              sort_keys: bool = False,
+              ack: bool = True,
+              tabs: int = 1
+              ) -> None:
     """
     see save_load_json_test()
     """
     json.dump(j, open(file_path, 'w'), indent=indent, sort_keys=sort_keys)
     if ack:
-        print('{}Saved: {}. Content: {}'.format(tabs * '\t', file_path,
-                                                json_to_string(j, indent=indent, sort_keys=sort_keys)))
+        size_s = mt.file_or_folder_size(file_path)
+        file_msg = '{}({})'.format(file_path, size_s)
+        print('{}{}. {}'.format(tabs * '\t', mt.SAVED.format(file_msg),
+                                mt.CONTENT.format(json_to_string(j, indent=indent, sort_keys=sort_keys))))
     return
-
-
-def get_key_by_value(d: dict, value) -> str:
-    """
-    :param d: dict
-    :param value:
-    Notice that it will return the first key of the value given. if value not unique...
-    :return: the key of the value
-    see get_key_by_value_test()
-    """
-    key = None
-    for k, v in d.items():
-        if v == value:
-            key = k
-            break
-    return key
