@@ -1,6 +1,6 @@
 """
-:requires: cv2
-:sub_package: wizzi_utils.pyplot
+:sub_package: wizzi_utils.socket
+:sub_package: wizzi_utils.open_cv
 """
 try:
     from wizzi_utils.open_cv.test.test_open_cv_tools import *
