@@ -1,5 +1,6 @@
 """
-:requires: matplotlib, mpl_toolkits
+:requires: matplotlib, mpl_toolkits,
+    torch for compare_images_multi_sets_squeezed()
 """
 try:
     from wizzi_utils.pyplot.pyplot_tools import *
