@@ -1,5 +1,6 @@
 """
-:requires: matplotlib, mpl_toolkits
+:requires: torch for compare_images_multi_sets_squeezed_test()
+:sub_package: open_cv with the test
 """
 try:
     from wizzi_utils.pyplot.test.test_pyplot_tools import *
