@@ -1,5 +1,8 @@
 import socket
-import numpy as np
+import os
+from urllib.request import urlretrieve
+from urllib.error import URLError
+from wizzi_utils.misc import misc_tools as mt
 
 
 def open_server(server_address: tuple = ('localhost', 10000), ack: bool = True, tabs: int = 1) -> socket:
@@ -93,16 +96,51 @@ def buffer_to_str(data: str, prefix: str, tabs: int = 1, max_chars: int = 100) -
     return msg
 
 
-def rounds_summary(times: list, tabs: int = 0) -> None:
+def download_file(url: str, dst_path: str = './file', tabs: int = 1) -> bool:
     """
-    :param times:
+    :param url:
+    :param dst_path: where to save the file.
+        if dst_path contains non existing folders - it will fail.
+            use mt.create_dir(dir) for new dirs
     :param tabs:
+    :return: bool 1 for success
+    see download_file_test()
+    see load_img_from_web() in test_open_cv_tools.py
     """
-    if len(times) > 0:  # try print time avg before exit
-        print('\n{}Rounds Summary:'.format(tabs * '\t'))
-        print('{}\tTotal rounds = {}'.format(tabs * '\t', len(times)))
-        print('{}\tTotal run time = {:.3f} seconds'.format(tabs * '\t', np.sum(times)))
-        print('{}\tAvg   run time = {:.3f} seconds (std = {:.3f})'.format(tabs * '\t', np.mean(times), np.std(times)))
-        if np.mean(times) > 0.0001:
-            print('{}\t{:.2f} FPS'.format(tabs * '\t', 1 / np.mean(times)))
-    return
+    filename = url.split('/')[-1]
+
+    def download_progress_hook(count, blockSize, totalSize):
+        if totalSize < 0:  # saw this once
+            percent = 'N\A'
+            size_s = 'size N\A'
+        else:
+            percent = '{:.1f}%'.format(min(float(count * blockSize) / float(totalSize) * 100.0, 100))
+            size_s = mt.convert_size(totalSize)
+        print("\r{}Completed: {} from {} - {}".format((tabs + 1) * '\t', percent, size_s, filename), end="")
+        return
+
+    ret = False
+    if not os.path.exists(dst_path):
+        try:
+            if mt.is_windows():
+                # in windows - add prefix which allows the file name to be longer than the default len (70 chars)
+                dst_path = mt.full_path_no_limit(dst_path)
+                if len(os.path.basename(dst_path)) > 255:
+                    err = 'len(os.path.basename(dst_path))={} exceeds the maximal length which is 255 chars. '
+                    err += 'dst_path = {}'
+                    mt.exception_error(err.format(len(os.path.basename(dst_path)), os.path.basename(dst_path)),
+                                       real_exception=False, tabs=tabs)
+                    return False
+            msg = 'Downloading from {} to {}'.format(url, dst_path)
+            print('{}{}'.format(tabs * '\t', mt.add_color(msg, ops='light_magenta')))
+            urlretrieve(url, dst_path, download_progress_hook)
+            print()  # release cartridge
+            ret = True
+        except URLError as e:
+            mt.exception_error('{} {}'.format(e, url), real_exception=True, tabs=tabs + 1)
+        except FileNotFoundError as e:
+            mt.exception_error('{}'.format(e), real_exception=True, tabs=tabs + 1)
+
+    else:
+        mt.exception_error(mt.EXISTS.format(dst_path), real_exception=False, tabs=tabs)
+    return ret
