@@ -1,6 +1,5 @@
 """
-:requires: socket, threading
-:sub_package: wizzi_utils.json
+:sub_package: json
 """
 try:
     from wizzi_utils.socket.test.test_socket_tools import *
